#include <stdio.h>
#include <string.h>
#include <stdarg.h>
#include <stdlib.h>
#include <syslog.h>
#include "nsql.h"

PUBLIC NSQL::NSQL(
	const char *server,
	const char *db)
{
	this->server = strdup(server);
	this->db = strdup(db);
	connected = 0;
}

PUBLIC NSQL::NSQL(NSQL_ARGS &args)
{
	this->server = strdup(args.server);
	this->db = strdup(args.db);
	connected = 0;
}

PUBLIC NSQL::~NSQL()
{
	free (server);
	free (db);
	disconnect();
}

PUBLIC int NSQL::disconnect()
{
	int ret = 0;
	if (connected){
		mysql_close (&my);
		connected = 0;
	}
	return ret;
}


PUBLIC int NSQL::connect()
{
	if (!connected){
		if (mysql_connect(&my,server,NULL,NULL)){
			if (!mysql_select_db(&my,db)){
				connected = 1;
			}
		}
	}
	return connected ? 0 : -1;
}

PUBLIC int NSQL::query (const char *req)
{
	int ret = -1;
	if (connect() != -1){
		ret = mysql_query (&my,req) ? -1 : 0;
	}else{
		fprintf (stderr,"No connection available\n");
		syslog (LOG_ERR,"Connection failed to MySql: %s"
			,error());
	}
	return ret;
}
PUBLIC int NSQL::queryf (const char *ctl, ...)
{
	char buf[10000];
	va_list list;
	va_start (list,ctl);
	vsprintf (buf,ctl,list);
	va_end (list);
	return query (buf);
}

/*
	Action query with no useful result set
*/
PUBLIC int NSQL::a_query (const char *req)
{
	int ret = query (req);
	if (ret != -1){
		MYSQL_RES *res = store_result();
		free_result(res);
	}
	return ret;
}
PUBLIC int NSQL::a_queryf (const char *ctl, ...)
{
	char buf[10000];
	va_list list;
	va_start (list,ctl);
	vsprintf (buf,ctl,list);
	va_end (list);
	return a_query (buf);
}

PUBLIC const char * NSQL::error ()
{
	return mysql_error(&my);
}

PUBLIC MYSQL_RES *NSQL::store_result()
{
	return mysql_store_result(&my);
}

PUBLIC void NSQL::free_result(MYSQL_RES *res)
{
	if (res != NULL) mysql_free_result(res);
}

PUBLIC int NSQL::numrows (MYSQL_RES *res)
{
	return mysql_num_rows (res);
}


PUBLIC NSQL_ARGS::NSQL_ARGS()
{
	server = db = NULL;
}
PUBLIC NSQL_ARGS::NSQL_ARGS(const char *_server, const char *_db)
{
	server = db = NULL;
	setserver (_server);
	setdb (_db);
}
PUBLIC NSQL_ARGS::~NSQL_ARGS()
{
	free (server);
	free (db);
}
PUBLIC void NSQL_ARGS::setserver( const char *s)
{
	free (server);
	server = NULL;
	if (s != NULL) server = strdup(s);
}
PUBLIC void NSQL_ARGS::setdb ( const char *s)
{
	free (db);
	db = NULL;
	if (s != NULL) db = strdup(s);
}

PUBLIC int NSQL_ARGS::isok()
{
	return server != NULL && db != NULL;
}


int nsql_parseargs(int argc, char *argv[], NSQL_ARGS &ar)
{
	int i;
	for (i=1; i<argc; i++){
		const char *arg = argv[i];
		if (strcmp(arg,"--server")==0){
			i++;
			if (i <argc){
				ar.setserver(argv[i]);
			}else{
				i = -1;
				break;
			}
		}else if (strcmp(arg,"--db")==0){
			i++;
			if (i <argc){
				ar.setdb(argv[i]);
			}else{
				i = -1;
				break;
			}
		}else{
			break;
		}
	}
	return i;	
}

const char *nsql_esc(const char *s)
{
	// Not done yet. A buffer must be allocated and some
	// character must be escaped.
	return s;
}

