#!/bin/sh
if [ $# = 0 ] ; then
	echo table.sh create [ mysql options ]
	echo table.sh delete [ mysql options ]
	echo Create the mailsql database
elif [ "$1" = "create" ] ; then
	shift
	mysqladmin create mailsql $*
	mysql mailsql $* <<-EOF
		create table domains (
			domainid int not null auto_increment primary key,
			domain varchar(100),
			unique (domain),
			quota	int default 0,
			fallback	varchar(100),
			mayreceive char default 'Y',
			mayretrieve char default 'Y'
		);
		create table daliases (
			domainid int not null,
			alias varchar(100),
			index (domainid,alias)
		);
		create table accounts (
			userid int not null auto_increment primary key,
			name varchar(30) not null,
			domainid int not null,
			unique (domainid,name),
			fullname varchar(50),
			quota int default 0,
			used int default 0,
			password varchar(50),
			lastaccess datetime,
			mayreceive char default 'Y',
			mayretrieve char default 'Y');
		create table folders (
			folderid int not null auto_increment primary key,
			userid int not null,
			foldername varchar(100) not null,
			unique (userid,foldername)
			);
		create table messages (
			messageid int not null auto_increment primary key,
			folderid int not null,
			index (folderid),
			fromname varchar(50),
			fromadr varchar(50),
			toname varchar(50),
			toadr varchar(50),
			reply varchar(50),
			subject varchar(200),
			msgid varchar(100),
			replyid varchar(100),
			datesent datetime,
			daterec timestamp,
			index (daterec),
			deleted char default 'N',
			header blob,
			size int);
		create table parts (
			messageid int,
			index (messageid),
			message longblob);
		create table aliases (
			name varchar(20) primary key,
			domainid int,
			alias varchar(200));
	EOF
elif [ "$1" = "delete" ] ; then
	shift
	mysqladmin drop mailsql $*
elif [ "$1" = "test" ] ; then
	shift
	mysql mailsql $* <<-EOF
		insert into domains (domain,domainid) values ("sql1.com",1);
		insert into daliases (alias,domainid) values ("sql1.com",1);
		insert into accounts (name,fullname,password,quota,domainid) values ('jack','Jacques Gelinas',password('foo'),100000,1);
		insert into folders (userid,foldername) values (1,'inbox');
		insert into aliases (name,domainid,alias) values ('joe',1,'jack@solucorp.qc.ca');
	EOF
fi

